@@ -113,9 +113,9 @@ class Size(object):
 
 
 class SSHKey(object):
-    def __init__(self, id, key):
+    def __init__(self, id, name):
         self.id = id
-        self.key = key
+        self.name = name
 
     def to_json(self):
         return self.__dict__
@@ -123,8 +123,8 @@ class SSHKey(object):
     @staticmethod
     def from_json(json):
         id = json.get('id', -1)
-        key = json.get('key', '')
-        ssh_key = SSHKey(id, key)
+        name = json.get('name', '')
+        ssh_key = SSHKey(id, name)
         return ssh_key
 
 
@@ -175,8 +175,8 @@ class Client(object):
         params = {}
         json = self.request('/ssh_keys', method='GET', params=params)
         ssh_keys_json = json.get('ssh_keys', [])
-        sizes = [Size.from_json(k) for k in ssh_keys_json]
-        return sizes
+        keys = [SSHKey.from_json(k) for k in ssh_keys_json]
+        return keys
 
     def reboot_droplet(self, id):
         params = {}
@@ -191,7 +191,7 @@ class Client(object):
         droplet = Droplet.from_json(droplet_json)
         return droplet
 
-    def create_droplet(self, name="", size_id=-1, image_id=-1, region_id=-1, ssh_key_ids = None):
+    def create_droplet(self, name="", size_id=-1, image_id=-1, region_id=-1, ssh_key_ids = None, virtio=False):
         params = {
             'name': name,
             'size_id': size_id,
@@ -200,7 +200,9 @@ class Client(object):
         }
         if ssh_key_ids:
             params['ssh_key_ids'] = ','.join(ssh_key_ids)
-
+        if virtio:
+            params['virtio'] = 1
+        
         json = self.request('/droplets/new', method='GET', params=params)
         droplet_json = json.get('droplet', None)
         droplet = Droplet.from_json(droplet_json)
